@@ -5,7 +5,7 @@ use warnings;
 use JSON::PP;
 use List::Util qw(sum min max);
 
-our $VERSION = '0.27';
+our $VERSION = '0.28';
 
 sub new {
     my ($class, %opts) = @_;
@@ -188,6 +188,16 @@ sub run_query {
             next;
         }
 
+        # support for group_by(key)
+        if ($part =~ /^group_by\((.+)\)$/) {
+            my $key_path = $1;
+            @next_results = map {
+                _group_by($_, $key_path)
+            } @results;
+            @results = @next_results;
+            next;
+        }
+
         # standard traversal
         for my $item (@results) {
             push @next_results, _traverse($item, $part);
@@ -430,6 +440,19 @@ sub _key {
     }
 }
 
+sub _group_by {
+    my ($array_ref, $path) = @_;
+    return {} unless ref $array_ref eq 'ARRAY';
+
+    my %groups;
+    for my $item (@$array_ref) {
+        my @keys = _traverse($item, $path);
+        my $key = defined $keys[0] ? "$keys[0]" : 'null';
+        push @{ $groups{$key} }, $item;
+    }
+    return \%groups;
+}
+
 1;
 __END__
 
@@ -441,7 +464,7 @@ JQ::Lite - A lightweight jq-like JSON query engine in Perl
 
 =head1 VERSION
 
-Version 0.27
+Version 0.28
 
 =head1 SYNOPSIS
 
@@ -480,6 +503,8 @@ jq-like syntax — entirely within Perl, with no external binaries or XS modules
 
 =item * Built-in functions: length, keys, first, last, reverse, sort, unique, has
 
+=item * group_by(...) to group array items by a key
+
 =item * Command-line interface: C<jq-lite>
 
 =item * Interactive mode for line-by-line query exploration
@@ -523,6 +548,8 @@ The return value is a list of matched results. Each result is a Perl scalar
 
 =item * select(.key > 1 and .key2 == "foo")
 
+=item * group_by(.field)
+
 =item * Functions: length, keys, first, last, reverse, sort, unique, has
 
 =item * .[] as alias for flattening top-level arrays
